@@ -5,10 +5,16 @@ use warnings;
 
 # ABSTRACT: A role that defines anything that processes something
 
-our $VERSION = '1.111860'; # VERSION
+our $VERSION = '1.111910'; # VERSION
 
 use Moose::Role;
 
+has 'name' => (
+    'is'        => 'ro',
+    'isa'       => 'Str',
+    'predicate' => 'has_name',
+);
+
 requires 'process';
 
 1;
@@ -25,7 +31,7 @@ DataFlow::Role::Processor - A role that defines anything that processes somethin
 
 =head1 VERSION
 
-version 1.111860
+version 1.111910
 
 =head1 SEE ALSO
 
